# authentic2 - versatile identity manager
# Copyright (C) 2010-2019 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.utils.translation import ugettext_lazy as _
import django.forms

from . import views, app_settings
from authentic2.utils import redirect_to_login


class SSLAuthenticator(object):
    def enabled(self):
        return app_settings.ENABLE

    def id(self):
        return 'ssl'

    def name(self):
        return _('SSL with certificates')

    def form(self):
        return django.forms.Form

    def post(self, request, form, nonce, next_url):
        return redirect_to_login(request, login_url='user_signin_ssl',)

    def template(self):
        return 'auth/login_form_ssl.html'

    def profile(self, request, *args, **kwargs):
        return views.profile(request, *args, **kwargs)
