# authentic2 - versatile identity manager
# Copyright (C) 2010-2019 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.shortcuts import render
from django.utils.translation import ugettext as _, ugettext_lazy

from . import views, app_settings, utils, constants
from .forms import authentication as authentication_forms


class LoginPasswordAuthenticator(object):
    submit_name = 'login-password-submit'

    def enabled(self):
        return app_settings.A2_AUTH_PASSWORD_ENABLE

    def name(self):
        return ugettext_lazy('Password')

    def id(self):
        return 'password'

    def login(self, request, *args, **kwargs):
        context = kwargs.get('context', {})
        is_post = request.method == 'POST' and self.submit_name in request.POST
        data = request.POST if is_post else None
        form = authentication_forms.AuthenticationForm(request=request, data=data)
        if app_settings.A2_ACCEPT_EMAIL_AUTHENTICATION:
            form.fields['username'].label = _('Username or email')
        if app_settings.A2_USERNAME_LABEL:
            form.fields['username'].label = app_settings.A2_USERNAME_LABEL
        is_secure = request.is_secure
        context['submit_name'] = self.submit_name
        if is_post:
            utils.csrf_token_check(request, form)
            if form.is_valid():
                if is_secure:
                    how = 'password-on-https'
                else:
                    how = 'password'
                if form.cleaned_data.get('remember_me'):
                    request.session['remember_me'] = True
                    request.session.set_expiry(app_settings.A2_USER_REMEMBER_ME)
                return utils.login(request, form.get_user(), how,
                                   service_slug=request.GET.get(constants.SERVICE_FIELD_NAME))
        context['form'] = form
        return render(request, 'authentic2/login_password_form.html', context)

    def profile(self, request, *args, **kwargs):
        return views.login_password_profile(request, *args, **kwargs)

    def registration(self, request, *args, **kwargs):
        context = kwargs.get('context', {})
        return render(request, 'authentic2/login_password_registration_form.html', context)
