# authentic2 - versatile identity manager
# Copyright (C) 2010-2019 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import pytest

from django.contrib.auth import get_user_model
from authentic2.models import Attribute

pytestmark = pytest.mark.django_db


def test_provision_attributes():
    from authentic2_auth_saml.adapters import AuthenticAdapter

    adapter = AuthenticAdapter()
    User = get_user_model()
    Attribute.objects.create(kind='title', name='title', label='title')

    user = User.objects.create()
    idp = {
        'A2_ATTRIBUTE_MAPPING': [
            {
                'attribute': 'email',
                'saml_attribute': 'mail',
                'mandatory': True,
            },
            {
                'attribute': 'title',
                'saml_attribute': 'title',
            },
        ]
    }

    saml_attributes = {
        u'mail': u'john.doe@example.com',
        u'title': u'Mr.',
    }
    adapter.finish_create_user(idp, saml_attributes, user)
    assert user.email == 'john.doe@example.com'
    assert user.attributes.title == 'Mr.'
    del saml_attributes['mail']
    with pytest.raises(ValueError):
        adapter.finish_create_user(idp, saml_attributes, user)
