# authentic2 - versatile identity manager
# Copyright (C) 2010-2019 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# authentic2

from utils import login
import pytest

from django.core.urlresolvers import reverse
from django.utils.six.moves.urllib.parse import urlparse

from authentic2.custom_user.models import User

pytestmark = pytest.mark.django_db


def test_profile(app, simple_user):
    page = login(app, simple_user, path=reverse('account_management'))
    assert simple_user.first_name in page
    assert simple_user.last_name in page


def test_password_change(app, simple_user):
    page = login(app, simple_user, path=reverse('auth_password_change'))
    page = page.form.submit('cancel').follow()


def test_account_delete(app, simple_user, mailoutbox):
    assert simple_user.is_active
    assert not len(mailoutbox)
    page = login(app, simple_user, path=reverse('delete_account'))
    page.form.set('password', simple_user.username)
    # FIXME: webtest does not set the Referer header, so the logout page will always ask for
    # confirmation under tests
    response = page.form.submit(name='submit').follow()
    response = response.form.submit()
    assert len(mailoutbox) == 1
    assert not User.objects.get(pk=simple_user.pk).is_active
    assert urlparse(response.location).path == '/'
    response = response.follow().follow()
    assert response.request.url.endswith('/login/?next=/')


def test_login_invalid_next(app):
    app.get(reverse('auth_login') + '?next=plop')


def test_custom_account(settings, app, simple_user):
    response = login(app, simple_user, path=reverse('account_management'))
    assert response.status_code == 200
    settings.A2_ACCOUNTS_URL = 'http://combo/account/'
    response = app.get(reverse('account_management'))
    assert response.status_code == 302
    assert response['Location'] == settings.A2_ACCOUNTS_URL
